pub fn execute_single_test_compiled(
ctx: CompiledTestContext<'_>,
) -> Result<(), TestErrorKind>Expand description
Execute a single test using compiled functions via the custom handler.
pub fn execute_single_test_compiled(
ctx: CompiledTestContext<'_>,
) -> Result<(), TestErrorKind>Execute a single test using compiled functions via the custom handler.