StateTestEvm

Type Alias StateTestEvm 

type StateTestEvm<'a> = MainnetEvm<MainnetContext<&'a mut State<EmptyDB>>>;

Aliased Type

struct StateTestEvm<'a> {
    pub ctx: Context<BlockEnv, TxEnv, CfgEnv, &'a mut State<EmptyDBTyped<Infallible>>>,
    pub inspector: (),
    pub instruction: EthInstructions<EthInterpreter, Context<BlockEnv, TxEnv, CfgEnv, &'a mut State<EmptyDBTyped<Infallible>>>>,
    pub precompiles: EthPrecompiles,
    pub frame_stack: FrameStack<EthFrame>,
}

Fields

ctx: Context<BlockEnv, TxEnv, CfgEnv, &'a mut State<EmptyDBTyped<Infallible>>>

[context_interface::ContextTr] of the EVM it is used to fetch data from database.

inspector: ()

Inspector of the EVM it is used to inspect the EVM. Its trait are defined in revm-inspector crate.

instruction: EthInstructions<EthInterpreter, Context<BlockEnv, TxEnv, CfgEnv, &'a mut State<EmptyDBTyped<Infallible>>>>

Instructions provider of the EVM it is used to execute instructions. InstructionProvider trait is defined in revm-handler crate.

precompiles: EthPrecompiles

Precompile provider of the EVM it is used to execute precompiles. PrecompileProvider trait is defined in revm-handler crate.

frame_stack: FrameStack<EthFrame>

Frame that is going to be executed.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 1056 bytes